==> xps_1.12.1.tar.gz: xps/man/madplot-methods.Rd <==
\name{madplot-methods}
\docType{methods}
\alias{madplot-methods}
\alias{madplot}
\title{Array-Array Expression Level Distance Plot}
\description{
 A false color display of between arrays distances, computed as the MAD of the M-values of
 each pair of arrays.

\emph{Usage}

\code{
madplot(x,
        which      = "UnitName",
        transfo    = log2,
        col        = NULL,
        names      = "namepart",
        sort       = FALSE,
        bmar       = NULL,
        add.legend = FALSE,
        ...) 
}
}
\arguments{
  \item{x}{object of class \code{\link{ExprTreeSet}}.}
  \item{transfo}{a valid function to transform the data, usually \dQuote{log2}, or \dQuote{0}.}
  \item{col}{vector of colors for plot, length is number of samples.}
  \item{names}{optional vector of sample names.}
  \item{sort}{logical, if TRUE the correlation matrix will be sorted decreasingly.}
  \item{bmar}{optional \code{list} for bottom margin and axis label magnification \code{cex.axis}.}
  \item{add.legend}{logical, if TRUE then a color bar will be drawn.}
  \item{\dots}{optional arguments to be passed to \code{plot}.}
}
\details{
 Produces a false color display, i.e. heatmap, of between arrays distances for slot \code{data}
 for an object of class \code{\link{ExprTreeSet}}, computed as the MAD of the M-values of each
 pair of arrays.

 For \code{names=NULL} full column names of slot \code{data} will be displayed while for 
 \code{names="namepart"} column names will be displayed without name extension. If \code{names}
 is a vector of column names, only these columns will displayed as mdaplot.

 For \code{bmar=NULL} the default list \code{bmar = list(b=6, cex.axis=1.0)} will be used initially.
 However, both bottom margin and axis label magnification will be adjusted depending on the number
 of label characters and the number of smaples.  
}
\author{Christian Stratowa}
\seealso{\code{\link{corplot}}}
\keyword{methods}

==> xps_1.26.1.tar.gz: xps/man/madplot-methods.Rd <==
\name{madplot-methods}
\docType{methods}
\alias{madplot-methods}
\alias{madplot}
\title{Array-Array Expression Level Distance Plot}
\description{
 A false color display of between arrays distances, computed as the MAD of the M-values of
 each pair of arrays.

\emph{Usage}

\code{
madplot(x,
        which      = "UnitName",
        transfo    = log2,
        col        = NULL,
        names      = "namepart",
        sort       = FALSE,
        bmar       = NULL,
        add.legend = FALSE,
        ...) 
}
}
\arguments{
  \item{x}{object of class \code{\link{ExprTreeSet}}.}
  \item{which}{type of probes to be used, for details see \code{\link{validData}}.}
  \item{transfo}{a valid function to transform the data, usually \dQuote{log2}, or \dQuote{0}.}
  \item{col}{vector of colors for plot, length is number of samples.}
  \item{names}{optional vector of sample names.}
  \item{sort}{logical, if TRUE the correlation matrix will be sorted decreasingly.}
  \item{bmar}{optional \code{list} for bottom margin and axis label magnification \code{cex.axis}.}
  \item{add.legend}{logical, if TRUE then a color bar will be drawn.}
  \item{\dots}{optional arguments to be passed to \code{plot}.}
}
\details{
 Produces a false color display, i.e. heatmap, of between array distances for slot \code{data}
 for an object of class \code{\link{ExprTreeSet}}, computed as the MAD of the M-values of each
 pair of arrays.

 For \code{names=NULL} full column names of slot \code{data} will be displayed while for 
 \code{names="namepart"} column names will be displayed without name extension. If \code{names}
 is a vector of column names, only these columns will displayed as mdaplot.

 For \code{bmar=NULL} the default list \code{bmar = list(b=6, cex.axis=1.0)} will be used initially.
 However, both bottom margin and axis label magnification will be adjusted depending on the number
 of label characters and the number of smaples.  
}
\author{Christian Stratowa}
\seealso{\code{\link{plotMAD}}, \code{\link{corplot}}}
\keyword{methods}
